Instagram Thief is a bot to "steal" someone else's instagram posts, and automatically post them to your account (obviously tagging the owner). There are 5 methods: login() to login into your account; downloadByFee(number_of_photos) to download photos from your instagram feed; downloadByHashtag(hashtags, number_of_photos), to download photos from hashtag(s); closeDB() to close the database (this method is essential for the bot to work, so always put it at the end of your bot); finally postToAccount(description_post) to post these photos in your account. To initialize the bot:
bot = thief() (bot you can replace it with any word).